@@ -12,6 +12,7 @@ pub mod csv;
 pub mod json;
 pub mod ids;
 pub mod ical;
+pub mod custom;
 
 #[derive(Debug, Clone, Serialize, Deserialize)]
 #[serde(rename_all = "lowercase")]
@@ -37,16 +38,18 @@ impl Formatter {
     /// to the local timezone is given in `offset` to prevent this function from
     /// using a secondary effect to retrieve the time and conver dates. This
     /// also makes it easier to test.
-    pub fn print_formatted<W: Write>(&self, entries: Vec<Entry>, out: &mut W, facts: &Facts, ids: bool) -> error::Result<()> {
+    pub fn print_formatted<O, E>(&self, entries: Vec<Entry>, out: &mut O, err: &mut E, facts: &Facts, ids: bool) -> error::Result<()>
+    where
+        O: Write,
+        E: Write,
+    {
         match &self {
             Formatter::Text => text::print_formatted(entries, out, facts, ids)?,
             Formatter::Csv => csv::print_formatted(entries, out, ids)?,
             Formatter::Json => json::print_formatted(entries, out)?,
             Formatter::Ids => ids::print_formatted(entries, out)?,
             Formatter::Ical => ical::print_formatted(entries, out, facts.now)?,
-            Formatter::Custom(name) => {
-                panic!("attempted custom formatter with name {} which is not implemented", name);
-            }
+            Formatter::Custom(name) => custom::print_formatted(name, entries, out, err, facts)?,
         }
 
         Ok(())
